class MetaInfo:
    def __init__(self):
        self.identifiers = None
        self.comments = None
        self.descriptions = None
        self.titles = None
        self.subjects = None
        self.publishers = None
        self.creators = None
        self.contributors = None
        self.audiences = None
        self.rights = None
        self.sameAs = None
        self.seeAlso = None
        self.hasSources = None
        self.doi = None
        self.date = None
